@@ -1,4 +1,3 @@
-use Mojo::Util qw(decode url_escape);
 sub Mojo::Weixin::_webwxupdatechatroom {
     my $self = shift;
     my $fun = shift;
@@ -13,7 +12,7 @@ sub Mojo::Weixin::_webwxupdatechatroom {
         my @query_string = (
             fun => 'modtopic',
         );
-        push @query_string,(pass_ticket =>  url_escape($self->pass_ticket)) if $self->pass_ticket;
+        push @query_string,(pass_ticket =>  $self->url_escape($self->pass_ticket)) if $self->pass_ticket;
         my $post = {
             BaseRequest =>  {
                 Uin         =>  $self->wxuin,
@@ -22,7 +21,7 @@ sub Mojo::Weixin::_webwxupdatechatroom {
                 DeviceID    =>  $self->deviceid,
             },
             ChatRoomName    =>  $group->id,
-            NewTopic        =>  decode("utf8",$displayname),
+            NewTopic        =>  $displayname,
         };
 
         my $json = $self->http_post($self->gen_url($api,@query_string),{json=>1,Referer=>'https://' . $self->domain . '/'},json=>$post); 
@@ -37,7 +36,7 @@ sub Mojo::Weixin::_webwxupdatechatroom {
         my @query_string = (
             fun => $mode,
         );
-        push @query_string,(pass_ticket =>  url_escape($self->pass_ticket)) if $self->pass_ticket;
+        push @query_string,(pass_ticket =>  $self->url_escape($self->pass_ticket)) if $self->pass_ticket;
         my $post = {
             BaseRequest =>  {
                 Uin         =>  $self->wxuin,
@@ -59,7 +58,7 @@ sub Mojo::Weixin::_webwxupdatechatroom {
         my @query_string = (
             fun => 'delmember',
         );
-        push @query_string,(pass_ticket =>  url_escape($self->pass_ticket)) if $self->pass_ticket;
+        push @query_string,(pass_ticket =>  $self->url_escape($self->pass_ticket)) if $self->pass_ticket;
         my $post = {
             BaseRequest =>  {
                 Uin         =>  $self->wxuin,
